@@ -32,15 +32,15 @@ class Snapshot:
 
 
 class ElasticsearchSnapshotMonitor:
-    def __init__(self, elasticsearch_repository: str, snapshots_prefix: str = '',
+    def __init__(self, elasticsearch_repository: str = 'found-snapshots', snapshots_prefix: str = '',
                  config: ElasticsearchConfig = ElasticsearchConfig()):
         self._log = Logging(ElasticsearchSnapshotMonitor.__name__, Logging.DEBUG)
 
         self._config = config if config == ElasticsearchConfig else ElasticsearchConfig()
         self._client = ElasticsearchClient(config=self._config)
-        self.connected = self._client.connected
+        self.connected = self._client.connected()
 
-        self._endpoint = self._client.config.es_hosts
+        self._endpoint = self._client._config.es_hosts
         self.repository = elasticsearch_repository
         self.snapshots_prefix = snapshots_prefix
 
@@ -92,8 +92,8 @@ class ElasticsearchSnapshotMonitor:
 
             return True
 
-        except Exception as _:
-            self._log.error('Unable to get snapshots')
+        except Exception as e:
+            self._log.error(f'Unable to get snapshots: {e}')
             self.error = SnapshotError(snapshots)
             return False
 
