@@ -1,6 +1,6 @@
 import unittest
 
-from automon.integrations.slack.slack import Slack, SlackError, BotInfo
+from automon.integrations.slack.client import SlackClient, SlackError, BotInfo
 from automon.integrations.slack.slack_logger import AsyncSlackLogging
 from automon.integrations.slack.config import ConfigSlack
 from automon.integrations.slack.slack_formatting import Format, Chat, Emoji
@@ -11,7 +11,7 @@ class SlackTest(unittest.TestCase):
         self.assertTrue(ConfigSlack())
 
     def test_Slack(self):
-        self.assertTrue(Slack())
+        self.assertTrue(SlackClient())
 
     def test_BotInfo(self):
         bot = {
@@ -47,14 +47,9 @@ class SlackTest(unittest.TestCase):
         self.assertIsNone(test.info('info'))
         self.assertIsNone(test.warn('warn'))
         self.assertIsNone(test.debug('debug'))
-        self.assertIsNone(test.debug('debug'))
-        self.assertIsNone(test.debug('debug'))
         self.assertIsNone(test.error('error'))
         self.assertIsNone(test.critical('critical'))
-        self.assertIsNone(test.test({1: 2}))
-        self.assertIsNone(test.test((1, 2)))
         self.assertIsNone(test.test('test'))
-        self.assertIsNone(test.test(None))
         self.assertIsNone(test.close())
 
     def test_Format(self):
